#-*- coding: utf-8 -*-

import sqlite3
import random
import math

from django.shortcuts import render, redirect
from grille_de_l_amour.carte.models import Pixel


def deg2num(lat_deg, lon_deg, zoom=16):
    """
        Formule qui permet d'obtenir le nom y/x de la tuile en fonction de ses coordonnées
        Récupérée ici : https://wiki.openstreetmap.org/wiki/Slippy_map_tilenames
    """

    lat_rad = math.radians(lat_deg)
    n = 2.0 ** zoom
    xtile = int((lon_deg + 180.0) / 360.0 * n)
    ytile = int((1.0 - math.log(math.tan(lat_rad) + (1 / math.cos(lat_rad))) / math.pi) / 2.0 * n)

    return (xtile, ytile)

def origine(request):
    """
        url proposée par défaut
    """

    # Orléans
    return redirect (page_carte, niv_zoom=14, latitude=47.9032, longitude=1.9114)

    # Nantes
    #return redirect (page_carte, niv_zoom=14, latitude=47.2138, longitude=-1.5562)


def page_carte(request, niv_zoom, latitude, longitude):
    """
        construit la portion de html constituée des <img> relatives aux tuiles
        et l'envoie au template de la carte (qui ne l'échappera pas)
    """

    # Correspondance entre les couleurs les les skins de CloudMade 
    # disponibles ici: http://maps.cloudmade.com/editor
    # Respecte l'orde des couleurs telles qu'affichées à l'écran dans la palette

    TAB_PALETTE = [
                '16340',        # noir
                '45499',        # blanc
                '33602',        # rouge 
                '36041',        # bleu
                '7543',         # vert 
                '39461',        # jaune
                '7134',         # violet
                '20538'         # turquoise
                ]

    LETTRE = ['a', 'a', 'c']

    #  ajustement nécéssaire entre le passage de 256*256 à 64*64
    zoom = int(niv_zoom) + 2 
    coord = deg2num(float(latitude), float(longitude), zoom)

    # pour recentrer
    y = coord[1] - 4
 
    top = 0
    cpt = 0
    grille = ''

    for i in range(10):

        # pour recentrer
        x = coord[0] - 6
 
        left = 0

        for j in range(13):

            for pixel in Pixel.objects.filter(nb = cpt):

                couleur_pixel = int(pixel.couleur)

            ligne = '<img class="tuile" style="left: {0}px; top: {1}px;" '.format(left, top)
            ligne += 'src="http://{0}.tile.cloudmade.com/75b297222833420cb33b584f6f2d24c8/'.format(LETTRE[random.randint(0, 2)])
            ligne += '{0}/64/{1}/{2}/{3}.png">\n'.format(TAB_PALETTE[couleur_pixel], zoom, x, y)

            grille += ligne
            x += 1
            left += 64
            cpt += 1

        y += 1
        top += 64

    return render(request, 'tpl_carte.html', {'liste_img': grille})
